package com.persagy.service.impl;

import java.util.List;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSONObject;
import com.persagy.cache.AlarmInfoCache;
import com.persagy.entity.AlarmState;
import com.persagy.entity.ExpireAlarmMessage;
import com.persagy.entity.ZktAlarmRecordDO;
import com.persagy.job.ExpireAlarmQueue;
import com.persagy.repository.AlarmRecordRepository;
import com.persagy.service.IAlarmRecordService;

import cn.hutool.core.collection.CollectionUtil;
import lombok.extern.slf4j.Slf4j;

/**
 * 
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2022年2月18日 上午10:06:54
 */
@Slf4j
@Service
public class AlarmRecordService implements IAlarmRecordService {

	@Autowired
    private AlarmRecordRepository alarmRecordRepository;
	
	@Override
    public void updateAlarmDefine(List<JSONObject> alarmDefineList) {
        if (CollectionUtil.isNotEmpty(alarmDefineList)) {
            for (JSONObject stateItem : alarmDefineList) {
                String defineId = AlarmInfoCache.getAlarmDefineId(stateItem);
                AlarmState alarmState = new AlarmState(defineId);
                String state = stateItem.getString("state");
                //1：未恢复；2：已恢复；3：已过期
                //报警状态（ 0-正常 1-报警）
                String newState = "1".equals(state) ? "1" : "0";
                alarmState.setState(newState);
                AlarmInfoCache.setAlarmState(defineId, alarmState);
                ZktAlarmRecordDO zktAlarmRecordDO = alarmRecordRepository.findById(defineId).orElse(new ZktAlarmRecordDO());
                zktAlarmRecordDO.setDefinitionId(defineId);
                zktAlarmRecordDO.setProjectId(stateItem.getString("projectId"));
                zktAlarmRecordDO.setObjId(stateItem.getString("objId"));
                zktAlarmRecordDO.setItemCode(stateItem.getString("itemCode"));
                zktAlarmRecordDO.setItemId(stateItem.getString("itemId"));
                zktAlarmRecordDO.setState(stateItem.getString("state"));
                alarmRecordRepository.save(zktAlarmRecordDO);
                if("2".equals(state)||"3".equals(state)) {
                    try {
                        ExpireAlarmMessage em = new ExpireAlarmMessage();
                        //取消过期消息
                        em.setType("2");
                        em.setJobName(defineId);
                        em.setJobGroupName("expire");
                        ExpireAlarmQueue.getExpireAlarmMessageQueue().produce(em);
                        //报警恢复，报警状态重置回默认
                        alarmState.reset();
                    }catch (Exception e){
                        log.error("取消过期定时任务失败",e);
                    }
                }
            }
        }
    }

	@Override
	public void save(ZktAlarmRecordDO zktAlarmRecordDO) {
		this.alarmRecordRepository.save(zktAlarmRecordDO);
	}

	@Override
	public Optional<ZktAlarmRecordDO> findById(String defineId) {
		return this.alarmRecordRepository.findById(defineId);
	}
	
}
